@@ -29,6 +29,7 @@
 #include "yelp-cache.h"
 #include "yelp-window.h"
 #include "yelp-theme.h"
+#include "yelp-pager.h"
 #include "yelp-toc-pager.h"
 #include "yelp-base.h"
 
@@ -88,7 +89,8 @@ impl_Yelp_getWindows (PortableServer_Servant  servant,
 		gchar *str_uri;
 
 		uri = yelp_window_get_current_uri (YELP_WINDOW (node->data));
-		str_uri = yelp_uri_to_string (uri);
+		str_uri = gnome_vfs_uri_to_string (uri->uri,
+						   GNOME_VFS_URI_HIDE_NONE);
 		list->_buffer[i] = CORBA_string_dup (str_uri);
 		g_free (str_uri);
 	}
@@ -202,8 +204,10 @@ yelp_base_new_window (YelpBase *base, const gchar *str_uri)
 
 	if (str_uri && strcmp (str_uri, ""))
 		uri = yelp_uri_new (str_uri);
-	else
-		uri = yelp_uri_new ("toc:");
+	else {
+		uri = yelp_pager_get_uri (YELP_PAGER (yelp_toc_pager_get ()));
+		yelp_uri_ref (uri);
+	}
 
 	yelp_window_open_uri (YELP_WINDOW (window), uri);
 
