@@ -1,6 +1,6 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #ifndef __YELP_WINDOW_H__
@@ -41,25 +41,24 @@ typedef struct _YelpWindowPriv   YelpWindowPriv;
 
 struct _YelpWindow
 {
-        GnomeApp        parent;
-        
-        YelpWindowPriv *priv;
+    GtkWindow       parent;
+
+    YelpWindowPriv *priv;
 };
 
 struct _YelpWindowClass
 {
-        GnomeAppClass   parent_class;
+    GtkWindowClass  paretn_class;
 
-        /* Signals */
-	void (*new_window_requested) (YelpWindow *window);
+    /* Signals */
+    void (*new_window_requested) (YelpWindow *window);
 };
 
 GType            yelp_window_get_type        (void);
 GtkWidget *      yelp_window_new             (GNode         *doc_tree,
 					      GList         *index);
-
 void             yelp_window_open_uri        (YelpWindow    *window,
-					      const gchar   *str_uri);
+					      YelpURI       *uri);
 YelpURI *        yelp_window_get_current_uri (YelpWindow    *window);
 
 #endif /* __YELP_WINDOW_H__ */
